'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function DefaultNavigator(_a) {
    var isNextAvailable = _a.isNextAvailable, isPrevAvailable = _a.isPrevAvailable, nextStep = _a.nextStep, prevStep = _a.prevStep;
    return (React.createElement("div", null,
        React.createElement("button", { type: "button", onClick: prevStep, disabled: !isPrevAvailable }, "Previous"),
        React.createElement("button", { type: "button", onClick: nextStep, disabled: !isNextAvailable }, "Next")));
}

var WizardContext = React.createContext({});
function WizardConsumer(_a) {
    var children = _a.children;
    return (React.createElement(WizardContext.Consumer, null, function (context) {
        if (Object.entries(context).length === 0 &&
            context.constructor === Object) {
            throw new Error('Components using WizardContext must be rendered within the Wizard component');
        }
        return children(context);
    }));
}

function Navigator(_a) {
    var children = _a.children;
    return (React.createElement(WizardConsumer, null, function (context) { return (children ? children(context) : DefaultNavigator(context)); }));
}

function DefaultStepTracker(_a) {
    var _b = _a.currentStep, currentStep = _b === void 0 ? 0 : _b, _c = _a.steps, steps = _c === void 0 ? [] : _c;
    return (React.createElement("div", { style: { display: 'block', padding: '25px' } },
        React.createElement("div", { style: {
                display: 'flex',
                flexDirection: 'row',
                justifyContent: 'space-between',
            } }, steps.map(function (step, index) {
            var key = index + "-" + step;
            return (React.createElement("div", { key: key, style: { display: 'block', textAlign: 'center' } },
                React.createElement("span", { style: {
                        display: 'inline-block',
                        borderRadius: '50%',
                        lineHeight: '2rem',
                        height: '30px',
                        width: '30px',
                        border: '0.1rem solid #ff161b',
                        background: currentStep >= index
                            ? 'linear-gradient(#ff161b,#ff009a)'
                            : 'white',
                        color: 'white',
                    } }, currentStep > index ? '✓' : null),
                React.createElement("div", null,
                    React.createElement("span", null, step ? index + 1 + ". " + step : ''))));
        }))));
}

function StepTracker(_a) {
    var children = _a.children;
    return (React.createElement(WizardConsumer, null, function (context) { return (children ? children(context) : DefaultStepTracker(context)); }));
}

function Steps(_a) {
    var children = _a.children;
    return (React.createElement(WizardContext.Consumer, null, function (context) {
        return context.totalSteps > 0
            ? React.Children.map(children, function (child, index) {
                return context.currentStep === index
                    ? React.cloneElement(child, {})
                    : null;
            })
            : null;
    }));
}

var WizardPropTypes = {
    children: function (props, propName, componentName) {
        var error = null;
        React.Children.forEach(props[propName], function (child) {
            if (![Navigator, StepTracker, Steps].some(function (component) { return component === child.type; })) {
                error = new Error(componentName + " children should only include components of types Wizard.Navigator or Wizard.Steps");
            }
        });
        return error;
    },
};
var getInitialState = function (props, handlers) {
    var totalSteps = 0;
    var steps = [];
    React.Children.forEach(props.children, function (child) {
        if (child.type === Steps && child.props.children) {
            totalSteps = child.props.children.length;
            React.Children.forEach(child.props.children, function (step) {
                steps = steps.concat(step.props.stepLabel);
            });
        }
    });
    var currentStep = 0;
    var isNextAvailable = currentStep < totalSteps - 1;
    var isPrevAvailable = currentStep > 0;
    var state = {
        steps: steps,
        currentStep: currentStep,
        totalSteps: totalSteps,
        isNextAvailable: isNextAvailable,
        isPrevAvailable: isPrevAvailable,
    };
    return __assign(__assign({}, state), handlers);
};
var Wizard = (function (_super) {
    __extends(Wizard, _super);
    function Wizard() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.handleStepChange = function (currentStep, totalSteps) {
            _this.setState({
                isNextAvailable: currentStep < totalSteps - 1,
                isPrevAvailable: currentStep > 0,
            }, function () {
                var onStepChange = _this.props.onStepChange;
                if (onStepChange)
                    onStepChange(currentStep);
            });
        };
        _this.nextStep = function () {
            var isNextAvailable = _this.state.isNextAvailable;
            if (isNextAvailable)
                _this.setState(function (prevState) { return ({
                    currentStep: prevState.currentStep + 1,
                }); });
        };
        _this.prevStep = function () {
            var isPrevAvailable = _this.state.isPrevAvailable;
            if (isPrevAvailable)
                _this.setState(function (prevState) { return ({
                    currentStep: prevState.currentStep - 1,
                }); });
        };
        _this.state = getInitialState(_this.props, {
            nextStep: _this.nextStep,
            prevStep: _this.prevStep,
        });
        return _this;
    }
    Wizard.prototype.componentDidUpdate = function (_, prevState) {
        var _a = this.state, currentStep = _a.currentStep, totalSteps = _a.totalSteps;
        if (prevState.currentStep !== currentStep)
            this.handleStepChange(currentStep, totalSteps);
    };
    Wizard.prototype.render = function () {
        var children = this.props.children;
        return (React.createElement("div", null,
            React.createElement(WizardContext.Provider, { value: this.state }, children)));
    };
    Wizard.Navigator = Navigator;
    Wizard.StepTracker = StepTracker;
    Wizard.Steps = Steps;
    Wizard.propTypes = {
        children: WizardPropTypes.children,
    };
    Wizard.defaultProps = {
        children: [],
    };
    return Wizard;
}(React.PureComponent));

exports.default = Wizard;
//# sourceMappingURL=index.js.map
